@@ -127,7 +127,7 @@ class APIServiceGenerator:
         # 生成端点函数
         endpoint_functions = []
         for endpoint in endpoints:
-            func_code = self._generate_endpoint_function(endpoint, service_class)
+            func_code = self._generate_endpoint_function(endpoint, table)
             endpoint_functions.append(func_code)
         
         # 组合完整代码
@@ -470,8 +470,13 @@ class APIServiceGenerator:
         
         return methods
     
-    def _generate_endpoint_function(self, endpoint: EndpointConfig, service_class: str) -> str:
+    def _generate_endpoint_function(self, endpoint: EndpointConfig, table: TableDefinition) -> str:
         """生成端点函数代码"""
+        # 获取模型名称和蛇形命名（与 _generate_api_content 保持一致）
+        model_name = self._to_pascal_case(table.name)
+        snake_name = self._to_snake_case(table.name)
+        service_class = f"{model_name}Service"
+        
         # 构建参数列表
         params = []
         service_args = []
@@ -497,9 +502,12 @@ class APIServiceGenerator:
         
         # 构建函数体
         if endpoint.service_method == "get_list":
-            function_body = f"""    # 创建一个空的过滤器参数
-    from schemas.{self._to_snake_case(service_class.replace('Service', ''))} import {service_class.replace('Service', '')}Filter
-    filter_params = {service_class.replace('Service', '')}Filter()
+            function_body = f"""    # 创建过滤器参数，使用 query 中的搜索条件
+    from schemas.{snake_name} import {model_name}Filter
+    filter_params = {model_name}Filter()
+    # 将 query 中的搜索条件传递给 filter_params
+    if hasattr(query, 'search') and query.search:
+        filter_params.search = query.search
     result = await service.{endpoint.service_method}({service_args_str}, filter_params, db)
     # 转换列表中的每个项目为字典
     from pyadvincekit.utils.serializers import sqlalchemy_to_dict
