@@ -13,8 +13,10 @@ from fastapi import FastAPI
 
 from pyadvincekit.core.router_discovery import auto_discover_and_register_routers
 from pyadvincekit.core.auto_api_manager import auto_discover_and_generate_apis
+from pyadvincekit.logging import  TraceMiddleware
 from pyadvincekit.core.config import get_settings
 from pyadvincekit.core.database import init_database
+from pyadvincekit.docs.decorators import api_category, api_doc, api_example
 
 
 def create_app_with_auto_discovery(
@@ -58,18 +60,58 @@ def create_app_with_auto_discovery(
     return app
 
 
-def create_app_with_router_discovery_only(
+# def create_app_with_router_discovery_only(
+@api_category("API开发", "路由创建")
+@api_doc(
+    title="自动路由注册应用创建",
+    description="创建FastAPI应用并自动发现和注册指定目录下的路由文件",
+    params={
+        "title": "应用标题（可选）",
+        "description": "应用描述（可选）",
+        "version": "应用版本（可选）",
+        "api_directory": "API路由文件目录（默认：api）",
+        "exclude_router_files": "排除的路由文件列表（可选）",
+        "auth_kwargs": "认证相关参数（可选）"
+    },
+    returns="FastAPI: 配置完成的FastAPI应用实例",
+    version="2.0.0"
+)
+@api_example('''
+# 基础用法：创建自动注册路由的应用
+app = create_app_auto_register()
+
+# 自定义配置：指定应用信息和API目录
+app = create_app_auto_register(
+    title="我的API服务",
+    description="基于PyAdvanceKit的API服务",
+    version="1.0.0",
+    api_directory="src/api"
+)
+
+# 排除特定路由：不注册某些路由文件
+app = create_app_auto_register(
+    api_directory="api",
+    exclude_router_files=["admin.py", "internal.py"]
+)
+
+# 启动应用
+import uvicorn
+uvicorn.run(app, host="0.0.0.0", port=8000)
+''', description="自动路由注册应用的创建和配置")
+def create_app_auto_register(
     title: Optional[str] = None,
     description: Optional[str] = None,
     version: Optional[str] = None,
     api_directory: str = "api",
     exclude_router_files: Optional[List[str]] = None,
+    **auth_kwargs
 ) -> FastAPI:
     """
-    创建只包含路由发现功能的 FastAPI 应用
+    创建路由自动发现注册功能
     
     这个函数只会自动发现和注册外部路由，不会生成自动 CRUD API。
     适用于已经生成了 API 和 Service 文件的项目。
+    自动调用 setup_all_middleware() 来启动所有中间件。
     
     Args:
         title: 应用标题
@@ -77,11 +119,14 @@ def create_app_with_router_discovery_only(
         version: 应用版本
         api_directory: API 文件目录
         exclude_router_files: 排除的路由文件列表
+        enable_auth: 是否启用身份校验中间件
+        **auth_kwargs: 身份校验中间件的额外参数
         
     Returns:
         配置好的 FastAPI 应用实例
     """
     from pyadvincekit.logging import get_logger
+    from pyadvincekit.core.middleware import setup_all_middleware
     logger = get_logger(__name__)
     
     # 1) 获取设置
@@ -112,6 +157,18 @@ def create_app_with_router_discovery_only(
     for router in routers:
         logger.info(f"注册路由: {router.prefix}, 标签: {router.tags}")
         app.include_router(router)
+    
+    # 5) 自动设置所有中间件
+    logger.info("开始设置所有中间件...")
+    enable_auth = settings.jwt_enable
+    setup_all_middleware(app, enable_auth=enable_auth, **auth_kwargs)
+    logger.info("所有中间件设置完成")
+
+    can_trace = settings.request_trace
+    if can_trace:
+        app.add_middleware(TraceMiddleware)
+
+
 
     return app
 
