@@ -291,6 +291,11 @@ class Settings(BaseSettings):
         default="/openapi.json",
         description="OpenAPI规范URL（None为禁用）"
     )
+
+    java_path: Optional[str] = Field(
+        default="http://localhost",
+        description="java对应登录接口"
+    )
     
     # 数据库配置
     database_url: str = Field(
