@@ -349,11 +349,11 @@ class DatabaseMetadataExtractor:
             logger.error(f"Failed to extract table {table_name}: {e}")
             return None
     
-    def _merge_constraints_to_columns(self, columns: List[TableColumn], constraints_by_column: Dict[str, List[ColumnConstraint]]):
-        """将约束信息合并到对应的列上"""
-        for column in columns:
-            if column.name in constraints_by_column:
-                column.constraints.extend(constraints_by_column[column.name])
+    # def _merge_constraints_to_columns(self, columns: List[TableColumn], constraints_by_column: Dict[str, List[ColumnConstraint]]):
+    #     """将约束信息合并到对应的列上"""
+    #     for column in columns:
+    #         if column.name in constraints_by_column:
+    #             column.constraints.extend(constraints_by_column[column.name])
     
     async def _get_table_columns(self, session: AsyncSession, table_name: str, db_type: str) -> List[TableColumn]:
         """获取表的列信息"""
@@ -513,6 +513,21 @@ class DatabaseMetadataExtractor:
         
         return constraints_by_column
     
+    def _merge_constraints_to_columns(self, columns: List[TableColumn], constraints_by_column: Dict[str, List[ColumnConstraint]]):
+        """将约束信息合并到对应的列上"""
+        for column in columns:
+            if column.name in constraints_by_column:
+                # 避免重复添加约束
+                existing_constraint_types = {c.type for c in column.constraints}
+                
+                for constraint in constraints_by_column[column.name]:
+                    # 只添加尚未存在的约束类型
+                    if constraint.type not in existing_constraint_types:
+                        column.constraints.append(constraint)
+                        logger.debug(f"Added constraint {constraint.type} to column {column.name}")
+                    else:
+                        logger.debug(f"Constraint {constraint.type} already exists for column {column.name}, skipping")
+    
     async def _get_table_indexes(self, session: AsyncSession, table_name: str, db_type: str) -> List[TableIndex]:
         """获取表的索引信息"""
         indexes = []
