@@ -398,10 +398,11 @@ USE `{design.name}`;
             col_def = self._generate_column_definition(column)
             column_definitions.append(f"  {col_def}")
             
-            # 收集主键
+            # 收集主键（避免重复）
             for constraint in column.constraints:
                 if constraint.type == ConstraintType.PRIMARY_KEY:
-                    primary_keys.append(column.name)
+                    if column.name not in primary_keys:  # 避免重复添加
+                        primary_keys.append(column.name)
         
         # 添加主键约束
         if primary_keys:
@@ -658,9 +659,12 @@ class ORMGenerator:
         # 检查表中的字段，决定使用哪些 Mixin
         original_field_names = [col.name for col in table.columns]
         
-        # 强制使用 IdMixin（小写 id），不管数据库中是否有 ID 字段
-        # 确保始终使用小写的 IdMixin
-        base_classes.append("IdMixin")
+        # 检查是否需要 IdMixin 或 UpperIdMixin（只有Excel中存在相应字段时才添加）
+        if "ID" in original_field_names:
+            base_classes.append("UpperIdMixin")
+        elif "id" in original_field_names:
+            base_classes.append("IdMixin")
+        # 如果Excel中没有id字段，就不添加任何IdMixin
         
         # 检查是否有时间戳字段
         timestamp_fields = {"created_at", "updated_at", "CREATED_AT", "UPDATED_AT"}
@@ -1070,28 +1074,6 @@ class ORMGenerator:
         
         return cleaned
     
-    def _determine_base_classes(self, table: TableDefinition) -> list:
-        """智能确定需要的基类和混入类"""
-        field_names = {col.name.lower() for col in table.columns}
-        original_field_names = {col.name for col in table.columns}  # 保留原始大小写
-        base_classes = ["BaseModel"]
-        
-        # 检查是否需要 IdMixin 或 UpperIdMixin
-        # 优先检查大写的 ID，因为这是数据库中更常见的情况
-        if "ID" in original_field_names:
-            base_classes.append("UpperIdMixin")
-        elif "id" in original_field_names:
-            base_classes.append("IdMixin")
-        
-        # 检查是否需要 TimestampMixin
-        if "created_at" in field_names or "updated_at" in field_names:
-            base_classes.append("TimestampMixin")
-        
-        # 检查是否需要 SoftDeleteMixin
-        if "is_deleted" in field_names or "deleted_at" in field_names:
-            base_classes.append("SoftDeleteMixin")
-        
-        return base_classes
     
     def _has_standard_fields(self, table: TableDefinition) -> bool:
         """检查表是否包含标准字段（id, created_at, updated_at）"""
@@ -1177,6 +1159,7 @@ class PydanticGenerator:
             "",
             f"class {self._to_pascal_case(table.name)}Filter(BaseModel):",
             '    """过滤条件模式"""',
+            "    search: Optional[str] = Field(default=None, description='搜索关键词')",
             "    # 可以根据需要添加具体的过滤字段",
         ])
         
